@@ -2,6 +2,7 @@
 # Function: attrisk.var
 # Programmer: Tom Kincaid
 # Date: November 2, 2010
+# Revised: March 30, 2020
 #
 #' Compute the Variance Estimate for Attributable Risk
 #'
@@ -170,7 +171,7 @@ attrisk.var <- function(response, stressor, response.levels, stressor.levels,
 # values or residuals and the variance of those totals for each stage one
 # sampling unit
       total2est <- matrix(0, ncluster, 4)
-      var2est <- array(0, c(4, 4, ncluster))
+      var2est <- matrix(0, ncluster, 16)
       for(i in 1:ncluster) {
 
 # Calculate the number of response values
@@ -183,7 +184,7 @@ attrisk.var <- function(response, stressor, response.levels, stressor.levels,
             stressor.levels[1])
          Ind3 <- (response.lst[[i]] == response.levels[1])*(stressor.lst[[i]] ==
             stressor.levels[2])
-         Ind3 <- (response.lst[[i]] == response.levels[2])*(stressor.lst[[i]] ==
+         Ind4 <- (response.lst[[i]] == response.levels[2])*(stressor.lst[[i]] ==
             stressor.levels[2])
 
 # Calculate the matrix of weighted indicator variables
@@ -221,26 +222,17 @@ attrisk.var <- function(response, stressor, response.levels, stressor.levels,
 # Calculate the variance-covariance estimate for the stage one sampling unit
          if(var.ind[i]) {
             if(vartype == "Local") {
-               weight.lst <- localmean.weight(x2.lst[[i]], y2.lst[[i]], 1/wgt2.lst[[i]])
-               var2est[i,] <- pcfactor*localmean.cov(rm, weight.lst)
+               weight.lst <- localmean.weight(x2.lst[[i]], y2.lst[[i]],
+                  1/wgt2.lst[[i]])
+               var2est[i,] <- as.vector(pcfactor*localmean.cov(rm, weight.lst))
             } else {
-               var2est[i,] <- pcfactor*nresp*var(rm)
+               var2est[i,] <- as.vector(pcfactor*nresp*var(rm))
                if(SRSind)
                   vartype <- "Local"
             }
          }
       }
 
-# Assign the mean variance to stage one sampling units with a single stage two
-# sampling unit
-      for(j in 1:4) {
-         ind <- var2est[,j] == 0
-         if(sum(ind) > 0) {
-            var.mean <- mean(var2est[!ind,j])
-            var2est[ind,j] <- var.mean
-         }
-      }
-
 # Adjust the variance-covariance estimator for small sample size
       if(vartype == "Local" && ncluster < 4) {
          warn.ind <- TRUE
@@ -265,16 +257,15 @@ attrisk.var <- function(response, stressor, response.levels, stressor.levels,
       pcfactor <- ifelse(pcfactor.ind, (N.cluster - ncluster)/N.cluster, 1)
 
 # Calculate the variance-covariance estimate
-      temp <- 0
-      for(i in 1:ncluster)
-         temp <- temp + var2est[,,i]*wgt1.u[i]
       if(vartype == "Local") {
          weight.lst <- localmean.weight(x1.u, y1.u, 1/wgt1.u)
          varest <- pcfactor*localmean.cov(total2est*matrix(rep(wgt1.u, 4),
-            nrow=ncluster), weight.lst) + temp
+            nrow=ncluster), weight.lst) + matrix(apply(var2est *
+            matrix(rep(wgt1.u, 16), nrow = ncluster), 2, sum), nrow=4)
       } else {
          varest <- pcfactor*ncluster*var(total2est*matrix(rep(wgt1.u, 4),
-            nrow=ncluster)) + temp
+            nrow=ncluster)) + matrix(apply(var2est*matrix(rep(wgt1.u, 16),
+            nrow = ncluster), 2, sum), nrow=4)
       }
 
 #
